package com.fastbee.data.controller.waterele;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.fastbee.common.annotation.Log;
import com.fastbee.common.core.controller.BaseController;
import com.fastbee.common.core.domain.AjaxResult;
import com.fastbee.common.enums.BusinessType;
import com.fastbee.waterele.domain.MaCardinfo;
import com.fastbee.waterele.service.IMaCardinfoService;
import com.fastbee.common.utils.poi.ExcelUtil;
import com.fastbee.common.core.page.TableDataInfo;

/**
 * 卡记录Controller
 *
 * @author kerwincui
 * @date 2024-08-12
 */
@RestController
@RequestMapping("/waterele/cardinfo")
@Api(tags = "卡记录")
public class MaCardinfoController extends BaseController
{
    @Autowired
    private IMaCardinfoService maCardinfoService;

/**
 * 查询卡记录列表
 */
@PreAuthorize("@ss.hasPermi('waterele:cardinfo:list')")
@GetMapping("/list")
@ApiOperation("查询卡记录列表")
    public TableDataInfo list(MaCardinfo maCardinfo)
    {
        startPage();
        List<MaCardinfo> list = maCardinfoService.selectMaCardinfoList(maCardinfo);
        return getDataTable(list);
    }

    /**
     * 导出卡记录列表
     */
    @ApiOperation("导出卡记录列表")
    @PreAuthorize("@ss.hasPermi('waterele:cardinfo:export')")
    @PostMapping("/export")
    public void export(HttpServletResponse response, MaCardinfo maCardinfo)
    {
        List<MaCardinfo> list = maCardinfoService.selectMaCardinfoList(maCardinfo);
        ExcelUtil<MaCardinfo> util = new ExcelUtil<MaCardinfo>(MaCardinfo.class);
        util.exportExcel(response, list, "卡记录数据");
    }

    /**
     * 获取卡记录详细信息
     */
    @PreAuthorize("@ss.hasPermi('waterele:cardinfo:query')")
    @GetMapping(value = "/{id}")
    @ApiOperation("获取卡记录详细信息")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(maCardinfoService.selectMaCardinfoById(id));
    }

    /**
     * 新增卡记录
     */
    @PreAuthorize("@ss.hasPermi('waterele:cardinfo:add')")
    @PostMapping
    @ApiOperation("新增卡记录")
    public AjaxResult add(@RequestBody MaCardinfo maCardinfo)
    {
        return toAjax(maCardinfoService.insertMaCardinfo(maCardinfo));
    }

    /**
     * 修改卡记录
     */
    @PreAuthorize("@ss.hasPermi('waterele:cardinfo:edit')")
    @PutMapping
    @ApiOperation("修改卡记录")
    public AjaxResult edit(@RequestBody MaCardinfo maCardinfo)
    {
        return toAjax(maCardinfoService.updateMaCardinfo(maCardinfo));
    }

    /**
     * 删除卡记录
     */
    @PreAuthorize("@ss.hasPermi('waterele:cardinfo:remove')")
    @DeleteMapping("/{ids}")
    @ApiOperation("删除卡记录")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(maCardinfoService.deleteMaCardinfoByIds(ids));
    }
}
